==> haskell-recursion-schemes-5.2.3-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-recursion-schemes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 recursion-schemes
version:              5.2.3
visibility:           public
id:                   recursion-schemes-5.2.3-BhpxYMZ2h9u4cZiqxOxonS
key:                  recursion-schemes-5.2.3-BhpxYMZ2h9u4cZiqxOxonS
license:              BSD-2-Clause
copyright:            Copyright (C) 2008-2015 Edward A. Kmett
maintainer:
    "Samuel Gélineau" <gelisam@gmail.com>,
    "Ryan Scott" <ryan.gl.scott@gmail.com>,
    "Luc Tielen" <luc.tielen@gmail.com>

author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/recursion-schemes/
synopsis:
    Representing common recursion patterns as higher-order functions

description:
    Many recursive functions share the same structure, e.g. pattern-match on the input and, depending on the data constructor, either recur on a smaller input or terminate the recursion with the base case. Another one: start with a seed value, use it to produce the first element of an infinite list, and recur on a modified seed in order to produce the rest of the list. Such a structure is called a recursion scheme. Using higher-order functions to implement those recursion schemes makes your code clearer, faster, and safer. See README for details.

category:             Control, Recursion
abi:                  ece0744d1a881710d875ca8e7a8d2909
exposed:              True
exposed-modules:
    Data.Functor.Base Data.Functor.Foldable Data.Functor.Foldable.TH

hidden-modules:       Paths_recursion_schemes
import-dirs:          /usr/lib/ghc-9.2.8/site-local/recursion-schemes-5.2.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/recursion-schemes-5.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recursion-schemes
hs-libraries:         HSrecursion-schemes-5.2.3-BhpxYMZ2h9u4cZiqxOxonS
depends:
    base-4.16.4.0 comonad-5.0.8-1Jw0cySHWTX5iwErc1G30B
    containers-0.6.5.1 data-fix-0.3.2-LAXNe0uFgyj9NF6NpjiS4q
    free-5.2-I49bMKgDBK7LoTwjaObXf0 template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-recursion-schemes/html/recursion-schemes.haddock

haddock-html:         /usr/share/doc/haskell-recursion-schemes/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-recursion-schemes-5.2.3-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-recursion-schemes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 recursion-schemes
version:              5.2.3
visibility:           public
id:                   recursion-schemes-5.2.3-KAqx8kP172l5B0MmwNHNFH
key:                  recursion-schemes-5.2.3-KAqx8kP172l5B0MmwNHNFH
license:              BSD-2-Clause
copyright:            Copyright (C) 2008-2015 Edward A. Kmett
maintainer:
    "Samuel Gélineau" <gelisam@gmail.com>,
    "Ryan Scott" <ryan.gl.scott@gmail.com>,
    "Luc Tielen" <luc.tielen@gmail.com>

author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/recursion-schemes/
synopsis:
    Representing common recursion patterns as higher-order functions

description:
    Many recursive functions share the same structure, e.g. pattern-match on the input and, depending on the data constructor, either recur on a smaller input or terminate the recursion with the base case. Another one: start with a seed value, use it to produce the first element of an infinite list, and recur on a modified seed in order to produce the rest of the list. Such a structure is called a recursion scheme. Using higher-order functions to implement those recursion schemes makes your code clearer, faster, and safer. See README for details.

category:             Control, Recursion
abi:                  57b423737e2155b69ae89136bd4af07b
exposed:              True
exposed-modules:
    Data.Functor.Base Data.Functor.Foldable Data.Functor.Foldable.TH

hidden-modules:       Paths_recursion_schemes
import-dirs:          /usr/lib/ghc-9.2.8/site-local/recursion-schemes-5.2.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/recursion-schemes-5.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recursion-schemes
hs-libraries:         HSrecursion-schemes-5.2.3-KAqx8kP172l5B0MmwNHNFH
depends:
    base-4.16.4.0 comonad-5.0.8-8xScyDaACinCtRgnxYXdM4
    containers-0.6.5.1 data-fix-0.3.2-LAXNe0uFgyj9NF6NpjiS4q
    free-5.2-7Yhsn64UzJE902IPfjDtFW template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-recursion-schemes/html/recursion-schemes.haddock

haddock-html:         /usr/share/doc/haskell-recursion-schemes/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
